@@ -17,10 +17,11 @@ from .conn_io import conn_io  # noqa
 from .conn_ccf import conn_ccf  # noqa
 from .conn_covgc import conn_covgc  # noqa
 from .conn_dfc import conn_dfc  # noqa
-from .conn_transfer_entropy import conn_transfer_entropy  # noqa
+from .conn_spec import conn_spec  # noqa
+from .conn_te import conn_te
 
 # connectivity utility functions
 from .conn_fcd_corr import conn_fcd_corr  # noqa
 from .conn_sliding_windows import define_windows, plot_windows  # noqa
-from .conn_utils import (conn_get_pairs, conn_reshape_undirected,  # noqa
-                         conn_reshape_directed, conn_ravel_directed)
+from .conn_utils import (conn_get_pairs, conn_links, conn_reshape_undirected,  # noqa
+                         conn_reshape_directed, conn_ravel_directed, conn_net)
