@@ -10,5 +10,8 @@ from .est_corr import CorrEstimator  # noqa
 # distance-based estimators
 from .est_dcorr import DcorrEstimator  # noqa
 
+# custom estimator
+from .est_custom import CustomEstimator  # noqa
+
 # resampling estimator
 from .est_resampling import ResamplingEstimator  # noqa
